###################################################
### chunk number 1: coin-setup
###################################################
#line 109 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
options(prompt = "R> ", continue = "+  ")
library("coin")
library("e1071")
set.seed(290875)

### extract slots of a class
c2t <- function(x) {        

    classdef <- getClassDef(x)

    extends <- names(classdef@contains)[1]
    if (!is.null(extends)) {
        eslots <- names(getClassDef(extends)@slots)
        slots <- classdef@slots[!names(classdef@slots) %in% eslots]
    } else {
        slots <- classdef@slots
    }

    RET <- cbind(names(slots), slots)
    attr(RET, "contains") <- extends 
    attr(RET, "name") <- x
    class(RET) <- "c2t"        
    RET
}
 
### pretty printing
toLatex.c2t <- function(object, center = TRUE, ...) {        

    RET <- c()

    if (center) RET <- c(RET, "\\begin{center}")

    ### class name
    RET <- c(RET, "\\begin{tabular}{ll}",
                  paste("\\multicolumn{2}{l}{Class \\Rclass{", 
                        attr(object, "name"), "}} \\\\", sep = "")) 

    ### extends?
    if (!is.null(attr(object, "contains")))
        RET <- c(RET, paste("\\multicolumn{2}{l}{Contains \\Rclass{", 
                            attr(object, "contains"), "}} \\\\", sep = ""))

    ### slots
    RET <- c(RET, " & \\\\", "Slot & Class \\\\ \\hline ",
             apply(object, 1, function(x) {
                 x <- cbind(paste("\\code{", x[1], "}", sep = ""),
                            paste("\\Rclass{", x[2], "}", sep = ""))
                 paste(paste(x, collapse = " & "), "\\\\")
             }),
             "\\hline")
    RET <- c(RET, "\\end{tabular}")

    if (center) RET <- c(RET, "\\end{center}")

    class(RET) <- "Latex"
    return(RET)
}


###################################################
### chunk number 2: Ex
###################################################
#line 254 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
library("coin")
data("rotarod", package = "coin")
independence_test(time ~ group, data = rotarod,
  ytrafo = rank, distribution = exact())


###################################################
### chunk number 3: IndependenceProblem
###################################################
#line 384 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("IndependenceProblem"))


###################################################
### chunk number 4: Ex-IndependenceProblem
###################################################
#line 393 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
ip <- new("IndependenceProblem",
  y = rotarod["time"], x = rotarod["group"])


###################################################
### chunk number 5: IndependenceTestProblem
###################################################
#line 403 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("IndependenceTestProblem"))


###################################################
### chunk number 6: Ex-IndependenceTestProblem
###################################################
#line 420 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
itp <- new("IndependenceTestProblem", ip, ytrafo = rank)


###################################################
### chunk number 7: IndependenceLinearStatistic
###################################################
#line 426 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("IndependenceLinearStatistic"))


###################################################
### chunk number 8: Ex-IndependenceLinearStatistic
###################################################
#line 434 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
ils <- new("IndependenceLinearStatistic", itp)


###################################################
### chunk number 9: Ex-IndependenceLinearStatistic-statistic
###################################################
#line 440 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
statistic(ils, "linear")


###################################################
### chunk number 10: Ex-IndependenceLinearStatistic-statistic
###################################################
#line 446 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
expectation(ils)
variance(ils)


###################################################
### chunk number 11: IndependenceTestStatistic
###################################################
#line 479 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("IndependenceTestStatistic"))


###################################################
### chunk number 12: Ex-IndependenceTestStatistic
###################################################
#line 486 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
its <- new("IndependenceTestStatistic", ils)


###################################################
### chunk number 13: ScalarIndependenceTestStatistic
###################################################
#line 504 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("ScalarIndependenceTestStatistic"))


###################################################
### chunk number 14: Ex-ScalarIndependenceTestStatistic
###################################################
#line 511 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
sits <- new("ScalarIndependenceTestStatistic", its,
  alternative = "two.sided")
statistic(sits, "standardized")


###################################################
### chunk number 15: MaxTypeIndependenceTestStatistic
###################################################
#line 531 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("MaxTypeIndependenceTestStatistic"))


###################################################
### chunk number 16: QuadTypeIndependenceTestStatistic
###################################################
#line 542 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("QuadTypeIndependenceTestStatistic"))


###################################################
### chunk number 17: PValue
###################################################
#line 583 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("PValue"))


###################################################
### chunk number 18: NullDistribution
###################################################
#line 587 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("NullDistribution"))


###################################################
### chunk number 19: Ex-NullDistribution-pvalue
###################################################
#line 634 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
end <- ExactNullDistribution(sits)
pvalue(end, statistic(sits))
qperm(end, 0.95)


###################################################
### chunk number 20: IndependenceTest
###################################################
#line 652 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
toLatex(c2t("IndependenceTest"))


###################################################
### chunk number 21: IndependenceTest
###################################################
#line 666 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
new("IndependenceTest", statistic = sits, distribution = end)


###################################################
### chunk number 22: Ex-distribution
###################################################
#line 779 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
set.seed(2908)
correxample <- data.frame(x = rnorm(7), y = rnorm(7))
sexact <- function(object) {
  x <- object@xtrans  
  y <- object@ytrans  
  perms <- permutations(nrow(x))
  pstats <- apply(perms, 1, function(p) sum(x[p,] * y))
  pstats <- (pstats - expectation(object)) / sqrt(variance(object)) 
  p <- function(q) 1 - mean(pstats > q)
  new("PValue", p = p, pvalue = p)
}


###################################################
### chunk number 23: Ex-distribution
###################################################
#line 798 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
independence_test(y ~ x, data = correxample, alternative = "less",
  distribution = sexact)


###################################################
### chunk number 24: 
###################################################
#line 831 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
mood_score <- function(y) (rank(y) - (nrow(y) + 1) / 2)^2


###################################################
### chunk number 25: 
###################################################
#line 836 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
ip <- new("IndependenceProblem",
  y = rotarod["time"], x = rotarod["group"])
itp <- new("IndependenceTestProblem", ip, 
  ytrafo = mood_score)
its <- new("IndependenceTestStatistic", itp)
sits <- new("ScalarIndependenceTestStatistic", its, 
  alternative = "two.sided")
new("ScalarIndependenceTest", statistic = sits,
  distribution = ExactNullDistribution(sits, algorithm = "split-up"))


###################################################
### chunk number 26: 
###################################################
#line 849 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
independence_test(time ~ group, data = rotarod, ytrafo = mood_score,
  distribution = exact(algorithm = "split-up"))


###################################################
### chunk number 27: js
###################################################
#line 926 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
data("jobsatisfaction", package = "coin")
js <- jobsatisfaction
dimnames(js)[[2]] <- c("VeryDiss", "LitSat", "ModSat", "VerySat")
ftable(Job.Satisfaction ~ Gender + Income, data = js)


###################################################
### chunk number 28: js-plot
###################################################
#line 935 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
library("vcd")
cotabplot(js,
  split_vertical = TRUE, spacing = spacing_highlighting,
  gp = gpar(fill = rev(gray.colors(4))),
  labeling_args = list(rot_labels = 0, varnames = FALSE,
    just_labels = c("center", "right")),  
  panel_args = list(margins = c(3, 1, 2, 3.5)))


###################################################
### chunk number 29: jobsatisfaction-it
###################################################
#line 953 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
it <- independence_test(js, teststat = "quad",
  distribution = asymptotic())
it


###################################################
### chunk number 30: jobsatisfaction-T
###################################################
#line 962 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
statistic(it, "linear")


###################################################
### chunk number 31: jobsatisfaction-margin
###################################################
#line 967 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
margin.table(js, 1:2)


###################################################
### chunk number 32: jobsatisfaction-stat
###################################################
#line 972 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
statistic(it, "standardized")


###################################################
### chunk number 33: jobsatisfaction-ordinal
###################################################
#line 982 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
it <- independence_test(js, distribution = approximate(B = 10000),
  scores = list(Job.Satisfaction = 1:4, Income = 1:4))
pvalue(it)


###################################################
### chunk number 34: jobsatisfaction-max
###################################################
#line 998 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
independence_test(js, teststat = "max")


###################################################
### chunk number 35: jobsatisfaction-minp
###################################################
#line 1006 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
pvalue(independence_test(js, teststat = "max"), method = "single-step")


###################################################
### chunk number 36: coin-doxygen eval=FALSE
###################################################
## #line 1033 "d:/Rcompile/CRANpkg/local/2.12/coin/inst/doc/coin_implementation.Rnw"
## browseURL(system.file("documentation", "html", "index.html",
##   package = "coin"))


